Usage
=====
All searches object are placed here.

Objects
-------

### SearchProvider
It a super class for all searches via search line in MAL.

All the other inheritance from it and changes some consts.

 * SearchAccountsProvider - find accounts.
 * SearchAnimesProvider - find animes.
 * SearchMangasProvider - find mangas.
